# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class Parameter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'value_type': 'str',
        'target_id': 'str',
        'created_in_version': 'str',
        'last_update_date_utc': 'datetime',
        'last_update_user': 'str',
        'version_id': 'str',
        'group_id': 'str',
        'parameter_definition': 'Calibration',
        'responsible': 'str'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'value_type': 'ValueType',
        'target_id': 'TargetId',
        'created_in_version': 'CreatedInVersion',
        'last_update_date_utc': 'LastUpdateDateUtc',
        'last_update_user': 'LastUpdateUser',
        'version_id': 'VersionId',
        'group_id': 'GroupId',
        'parameter_definition': 'ParameterDefinition',
        'responsible': 'Responsible'
    }

    def __init__(self, id=None, name=None, value_type=None, target_id=None, created_in_version=None, last_update_date_utc=None, last_update_user=None, version_id=None, group_id=None, parameter_definition=None, responsible=None, _configuration=None):  # noqa: E501
        """Parameter - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._value_type = None
        self._target_id = None
        self._created_in_version = None
        self._last_update_date_utc = None
        self._last_update_user = None
        self._version_id = None
        self._group_id = None
        self._parameter_definition = None
        self._responsible = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.value_type = value_type
        self.target_id = target_id
        if created_in_version is not None:
            self.created_in_version = created_in_version
        if last_update_date_utc is not None:
            self.last_update_date_utc = last_update_date_utc
        if last_update_user is not None:
            self.last_update_user = last_update_user
        self.version_id = version_id
        if group_id is not None:
            self.group_id = group_id
        if parameter_definition is not None:
            self.parameter_definition = parameter_definition
        if responsible is not None:
            self.responsible = responsible

    @property
    def id(self):
        """Gets the id of this Parameter.  # noqa: E501

        The unique parameter id  # noqa: E501

        :return: The id of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Parameter.

        The unique parameter id  # noqa: E501

        :param id: The id of this Parameter.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Parameter.  # noqa: E501

        The parameter name  # noqa: E501

        :return: The name of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Parameter.

        The parameter name  # noqa: E501

        :param name: The name of this Parameter.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def value_type(self):
        """Gets the value_type of this Parameter.  # noqa: E501

        The parameter value type   None = 0, String = 1, Double = 2, Integer = 3  # noqa: E501

        :return: The value_type of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._value_type

    @value_type.setter
    def value_type(self, value_type):
        """Sets the value_type of this Parameter.

        The parameter value type   None = 0, String = 1, Double = 2, Integer = 3  # noqa: E501

        :param value_type: The value_type of this Parameter.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and value_type is None:
            raise ValueError("Invalid value for `value_type`, must not be `None`")  # noqa: E501
        allowed_values = ["None", "String", "Double", "Integer"]  # noqa: E501
        if (self._configuration.client_side_validation and
                value_type not in allowed_values):
            raise ValueError(
                "Invalid value for `value_type` ({0}), must be one of {1}"  # noqa: E501
                .format(value_type, allowed_values)
            )

        self._value_type = value_type

    @property
    def target_id(self):
        """Gets the target_id of this Parameter.  # noqa: E501

        The target id to which the parameter belongs to.  Parameters are linked to the version through the VersionParam object.  But you don't have to care about this. Just call th parameters Api function and provide a version id to which you want to get the parameters.  # noqa: E501

        :return: The target_id of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this Parameter.

        The target id to which the parameter belongs to.  Parameters are linked to the version through the VersionParam object.  But you don't have to care about this. Just call th parameters Api function and provide a version id to which you want to get the parameters.  # noqa: E501

        :param target_id: The target_id of this Parameter.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and target_id is None:
            raise ValueError("Invalid value for `target_id`, must not be `None`")  # noqa: E501

        self._target_id = target_id

    @property
    def created_in_version(self):
        """Gets the created_in_version of this Parameter.  # noqa: E501

        The first version to which the parameter has been created for.  # noqa: E501

        :return: The created_in_version of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._created_in_version

    @created_in_version.setter
    def created_in_version(self, created_in_version):
        """Sets the created_in_version of this Parameter.

        The first version to which the parameter has been created for.  # noqa: E501

        :param created_in_version: The created_in_version of this Parameter.  # noqa: E501
        :type: str
        """

        self._created_in_version = created_in_version

    @property
    def last_update_date_utc(self):
        """Gets the last_update_date_utc of this Parameter.  # noqa: E501

        The last utc date time when the properties of the paremeter have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_date_utc of this Parameter.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_date_utc

    @last_update_date_utc.setter
    def last_update_date_utc(self, last_update_date_utc):
        """Sets the last_update_date_utc of this Parameter.

        The last utc date time when the properties of the paremeter have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_date_utc: The last_update_date_utc of this Parameter.  # noqa: E501
        :type: datetime
        """

        self._last_update_date_utc = last_update_date_utc

    @property
    def last_update_user(self):
        """Gets the last_update_user of this Parameter.  # noqa: E501

        The name of the last user having updated the parameter.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_user of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._last_update_user

    @last_update_user.setter
    def last_update_user(self, last_update_user):
        """Sets the last_update_user of this Parameter.

        The name of the last user having updated the parameter.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_user: The last_update_user of this Parameter.  # noqa: E501
        :type: str
        """

        self._last_update_user = last_update_user

    @property
    def version_id(self):
        """Gets the version_id of this Parameter.  # noqa: E501

        The version Id to which the parameter is linked  # noqa: E501

        :return: The version_id of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this Parameter.

        The version Id to which the parameter is linked  # noqa: E501

        :param version_id: The version_id of this Parameter.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and version_id is None:
            raise ValueError("Invalid value for `version_id`, must not be `None`")  # noqa: E501

        self._version_id = version_id

    @property
    def group_id(self):
        """Gets the group_id of this Parameter.  # noqa: E501

        The group id to which the parameter is located.   Or Guid.Empty (00000000-0000-0000-0000-000000000000) if the paramater is located on the root.  # noqa: E501

        :return: The group_id of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this Parameter.

        The group id to which the parameter is located.   Or Guid.Empty (00000000-0000-0000-0000-000000000000) if the paramater is located on the root.  # noqa: E501

        :param group_id: The group_id of this Parameter.  # noqa: E501
        :type: str
        """

        self._group_id = group_id

    @property
    def parameter_definition(self):
        """Gets the parameter_definition of this Parameter.  # noqa: E501


        :return: The parameter_definition of this Parameter.  # noqa: E501
        :rtype: Calibration
        """
        return self._parameter_definition

    @parameter_definition.setter
    def parameter_definition(self, parameter_definition):
        """Sets the parameter_definition of this Parameter.


        :param parameter_definition: The parameter_definition of this Parameter.  # noqa: E501
        :type: Calibration
        """

        self._parameter_definition = parameter_definition

    @property
    def responsible(self):
        """Gets the responsible of this Parameter.  # noqa: E501

        The parameter's responsible name for the specified version  # noqa: E501

        :return: The responsible of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._responsible

    @responsible.setter
    def responsible(self, responsible):
        """Sets the responsible of this Parameter.

        The parameter's responsible name for the specified version  # noqa: E501

        :param responsible: The responsible of this Parameter.  # noqa: E501
        :type: str
        """

        self._responsible = responsible

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Parameter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Parameter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Parameter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class Track(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'last_update_date_utc': 'datetime',
        'last_update_user': 'str',
        'revision': 'int'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'last_update_date_utc': 'LastUpdateDateUtc',
        'last_update_user': 'LastUpdateUser',
        'revision': 'Revision'
    }

    def __init__(self, id=None, name=None, last_update_date_utc=None, last_update_user=None, revision=None, _configuration=None):  # noqa: E501
        """Track - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._last_update_date_utc = None
        self._last_update_user = None
        self._revision = None
        self.discriminator = None

        self.id = id
        self.name = name
        if last_update_date_utc is not None:
            self.last_update_date_utc = last_update_date_utc
        if last_update_user is not None:
            self.last_update_user = last_update_user
        if revision is not None:
            self.revision = revision

    @property
    def id(self):
        """Gets the id of this Track.  # noqa: E501

        The unique track Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Track.  # noqa: E501

        :return: The id of this Track.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Track.

        The unique track Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Track.  # noqa: E501

        :param id: The id of this Track.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Track.  # noqa: E501

        The track name  # noqa: E501

        :return: The name of this Track.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Track.

        The track name  # noqa: E501

        :param name: The name of this Track.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def last_update_date_utc(self):
        """Gets the last_update_date_utc of this Track.  # noqa: E501

        The last utc date time when the properties of this object have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_date_utc of this Track.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_date_utc

    @last_update_date_utc.setter
    def last_update_date_utc(self, last_update_date_utc):
        """Sets the last_update_date_utc of this Track.

        The last utc date time when the properties of this object have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_date_utc: The last_update_date_utc of this Track.  # noqa: E501
        :type: datetime
        """

        self._last_update_date_utc = last_update_date_utc

    @property
    def last_update_user(self):
        """Gets the last_update_user of this Track.  # noqa: E501

        The name of the last user having updated this object.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_user of this Track.  # noqa: E501
        :rtype: str
        """
        return self._last_update_user

    @last_update_user.setter
    def last_update_user(self, last_update_user):
        """Sets the last_update_user of this Track.

        The name of the last user having updated this object.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_user: The last_update_user of this Track.  # noqa: E501
        :type: str
        """

        self._last_update_user = last_update_user

    @property
    def revision(self):
        """Gets the revision of this Track.  # noqa: E501

        The revision number of the object.  # noqa: E501

        :return: The revision of this Track.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this Track.

        The revision number of the object.  # noqa: E501

        :param revision: The revision of this Track.  # noqa: E501
        :type: int
        """

        self._revision = revision

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Track, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Track):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Track):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class CompareOptions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'parameters_selection_filters': 'list[str]',
        'exclude_parameters_in_selection': 'bool',
        'diff_file_path': 'str',
        'diff_group': 'str'
    }

    attribute_map = {
        'parameters_selection_filters': 'ParametersSelectionFilters',
        'exclude_parameters_in_selection': 'ExcludeParametersInSelection',
        'diff_file_path': 'DiffFilePath',
        'diff_group': 'DiffGroup'
    }

    def __init__(self, parameters_selection_filters=None, exclude_parameters_in_selection=None, diff_file_path=None, diff_group=None, _configuration=None):  # noqa: E501
        """CompareOptions - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._parameters_selection_filters = None
        self._exclude_parameters_in_selection = None
        self._diff_file_path = None
        self._diff_group = None
        self.discriminator = None

        if parameters_selection_filters is not None:
            self.parameters_selection_filters = parameters_selection_filters
        if exclude_parameters_in_selection is not None:
            self.exclude_parameters_in_selection = exclude_parameters_in_selection
        if diff_file_path is not None:
            self.diff_file_path = diff_file_path
        if diff_group is not None:
            self.diff_group = diff_group

    @property
    def parameters_selection_filters(self):
        """Gets the parameters_selection_filters of this CompareOptions.  # noqa: E501

        The parameters selection filter  # noqa: E501

        :return: The parameters_selection_filters of this CompareOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._parameters_selection_filters

    @parameters_selection_filters.setter
    def parameters_selection_filters(self, parameters_selection_filters):
        """Sets the parameters_selection_filters of this CompareOptions.

        The parameters selection filter  # noqa: E501

        :param parameters_selection_filters: The parameters_selection_filters of this CompareOptions.  # noqa: E501
        :type: list[str]
        """

        self._parameters_selection_filters = parameters_selection_filters

    @property
    def exclude_parameters_in_selection(self):
        """Gets the exclude_parameters_in_selection of this CompareOptions.  # noqa: E501

        Exclude the parameters in the selection  # noqa: E501

        :return: The exclude_parameters_in_selection of this CompareOptions.  # noqa: E501
        :rtype: bool
        """
        return self._exclude_parameters_in_selection

    @exclude_parameters_in_selection.setter
    def exclude_parameters_in_selection(self, exclude_parameters_in_selection):
        """Sets the exclude_parameters_in_selection of this CompareOptions.

        Exclude the parameters in the selection  # noqa: E501

        :param exclude_parameters_in_selection: The exclude_parameters_in_selection of this CompareOptions.  # noqa: E501
        :type: bool
        """

        self._exclude_parameters_in_selection = exclude_parameters_in_selection

    @property
    def diff_file_path(self):
        """Gets the diff_file_path of this CompareOptions.  # noqa: E501

        The output file path contenaing the differences  # noqa: E501

        :return: The diff_file_path of this CompareOptions.  # noqa: E501
        :rtype: str
        """
        return self._diff_file_path

    @diff_file_path.setter
    def diff_file_path(self, diff_file_path):
        """Sets the diff_file_path of this CompareOptions.

        The output file path contenaing the differences  # noqa: E501

        :param diff_file_path: The diff_file_path of this CompareOptions.  # noqa: E501
        :type: str
        """

        self._diff_file_path = diff_file_path

    @property
    def diff_group(self):
        """Gets the diff_group of this CompareOptions.  # noqa: E501

        The diffence group (A or B) to use to generate the diff file when DiffFilePath is filled  # noqa: E501

        :return: The diff_group of this CompareOptions.  # noqa: E501
        :rtype: str
        """
        return self._diff_group

    @diff_group.setter
    def diff_group(self, diff_group):
        """Sets the diff_group of this CompareOptions.

        The diffence group (A or B) to use to generate the diff file when DiffFilePath is filled  # noqa: E501

        :param diff_group: The diff_group of this CompareOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["A", "B"]  # noqa: E501
        if (self._configuration.client_side_validation and
                diff_group not in allowed_values):
            raise ValueError(
                "Invalid value for `diff_group` ({0}), must be one of {1}"  # noqa: E501
                .format(diff_group, allowed_values)
            )

        self._diff_group = diff_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CompareOptions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompareOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CompareOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class UserApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def user_get_current_user(self, **kwargs):  # noqa: E501
        """Get the current TeamDB user.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_get_current_user(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_get_current_user_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.user_get_current_user_with_http_info(**kwargs)  # noqa: E501
            return data

    def user_get_current_user_with_http_info(self, **kwargs):  # noqa: E501
        """Get the current TeamDB user.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_get_current_user_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_get_current_user" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/user/current', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='User',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_get_user_group(self, user_group_id, **kwargs):  # noqa: E501
        """Get a TeamDB user group via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_get_user_group(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: The unique TeamDB user group id for which you want to get the user group (required)
        :return: UserGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_get_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.user_get_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
            return data

    def user_get_user_group_with_http_info(self, user_group_id, **kwargs):  # noqa: E501
        """Get a TeamDB user group via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_get_user_group_with_http_info(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: The unique TeamDB user group id for which you want to get the user group (required)
        :return: UserGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_get_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_group_id' is set
        if self.api_client.client_side_validation and ('user_group_id' not in params or
                                                       params['user_group_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_group_id` when calling `user_get_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_group_id' in params:
            path_params['userGroupId'] = params['user_group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/usergroup/{userGroupId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserGroup',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_get_user_groups(self, **kwargs):  # noqa: E501
        """Get the list of all TeamDB user groups  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_get_user_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[UserGroup]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_get_user_groups_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.user_get_user_groups_with_http_info(**kwargs)  # noqa: E501
            return data

    def user_get_user_groups_with_http_info(self, **kwargs):  # noqa: E501
        """Get the list of all TeamDB user groups  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_get_user_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[UserGroup]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_get_user_groups" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/usergroups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[UserGroup]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_get_user(self, user_id, **kwargs):  # noqa: E501
        """Get a TeamDB user via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_get_user(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The unique TeamDB user id for which you want to get the user (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_get_user_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.user_get_user_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def user_get_user_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Get a TeamDB user via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_get_user_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The unique TeamDB user id for which you want to get the user (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_get_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in params or
                                                       params['user_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `user_get_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/user/{userId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='User',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_get_users(self, **kwargs):  # noqa: E501
        """Get the list of all TeamDB users  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_get_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[User]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_get_users_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.user_get_users_with_http_info(**kwargs)  # noqa: E501
            return data

    def user_get_users_with_http_info(self, **kwargs):  # noqa: E501
        """Get the list of all TeamDB users  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_get_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[User]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_get_users" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[User]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class Version(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'created_date': 'datetime',
        'reference_files': 'str',
        'target_id': 'str',
        'auto_generate_assembly_id': 'str',
        'last_update_date_utc': 'datetime',
        'last_update_user': 'str',
        'replication_filter': 'str'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'description': 'Description',
        'created_date': 'CreatedDate',
        'reference_files': 'ReferenceFiles',
        'target_id': 'TargetId',
        'auto_generate_assembly_id': 'AutoGenerateAssemblyId',
        'last_update_date_utc': 'LastUpdateDateUtc',
        'last_update_user': 'LastUpdateUser',
        'replication_filter': 'ReplicationFilter'
    }

    def __init__(self, id=None, name=None, description=None, created_date=None, reference_files=None, target_id=None, auto_generate_assembly_id=None, last_update_date_utc=None, last_update_user=None, replication_filter=None, _configuration=None):  # noqa: E501
        """Version - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._description = None
        self._created_date = None
        self._reference_files = None
        self._target_id = None
        self._auto_generate_assembly_id = None
        self._last_update_date_utc = None
        self._last_update_user = None
        self._replication_filter = None
        self.discriminator = None

        self.id = id
        self.name = name
        if description is not None:
            self.description = description
        self.created_date = created_date
        self.reference_files = reference_files
        self.target_id = target_id
        if auto_generate_assembly_id is not None:
            self.auto_generate_assembly_id = auto_generate_assembly_id
        if last_update_date_utc is not None:
            self.last_update_date_utc = last_update_date_utc
        if last_update_user is not None:
            self.last_update_user = last_update_user
        if replication_filter is not None:
            self.replication_filter = replication_filter

    @property
    def id(self):
        """Gets the id of this Version.  # noqa: E501

        The unique version Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Version.  # noqa: E501

        :return: The id of this Version.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Version.

        The unique version Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Version.  # noqa: E501

        :param id: The id of this Version.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Version.  # noqa: E501

        The version name  # noqa: E501

        :return: The name of this Version.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Version.

        The version name  # noqa: E501

        :param name: The name of this Version.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this Version.  # noqa: E501

        The version description  # noqa: E501

        :return: The description of this Version.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Version.

        The version description  # noqa: E501

        :param description: The description of this Version.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def created_date(self):
        """Gets the created_date of this Version.  # noqa: E501

        The version creation date.  The date must be an UTC date time. Here is an example : 2018-06-05T12:36:34.168Z  # noqa: E501

        :return: The created_date of this Version.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this Version.

        The version creation date.  The date must be an UTC date time. Here is an example : 2018-06-05T12:36:34.168Z  # noqa: E501

        :param created_date: The created_date of this Version.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    @property
    def reference_files(self):
        """Gets the reference_files of this Version.  # noqa: E501

        The path to the file used to create the version.  In json, you have to double the \\ in the path. For example : C:\\\\\\\\MyFolder\\\\\\\\MyFile.m  # noqa: E501

        :return: The reference_files of this Version.  # noqa: E501
        :rtype: str
        """
        return self._reference_files

    @reference_files.setter
    def reference_files(self, reference_files):
        """Sets the reference_files of this Version.

        The path to the file used to create the version.  In json, you have to double the \\ in the path. For example : C:\\\\\\\\MyFolder\\\\\\\\MyFile.m  # noqa: E501

        :param reference_files: The reference_files of this Version.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and reference_files is None:
            raise ValueError("Invalid value for `reference_files`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                reference_files is not None and len(reference_files) < 1):
            raise ValueError("Invalid value for `reference_files`, length must be greater than or equal to `1`")  # noqa: E501

        self._reference_files = reference_files

    @property
    def target_id(self):
        """Gets the target_id of this Version.  # noqa: E501

        The target unique id to which the version belongs to.  # noqa: E501

        :return: The target_id of this Version.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this Version.

        The target unique id to which the version belongs to.  # noqa: E501

        :param target_id: The target_id of this Version.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and target_id is None:
            raise ValueError("Invalid value for `target_id`, must not be `None`")  # noqa: E501

        self._target_id = target_id

    @property
    def auto_generate_assembly_id(self):
        """Gets the auto_generate_assembly_id of this Version.  # noqa: E501

        The assembly unique Id used as reference when AutoGenerateAssembly is activated on the parent target.  Otherwise, set the property to Guid.Empty (00000000-0000-0000-0000-000000000000).  # noqa: E501

        :return: The auto_generate_assembly_id of this Version.  # noqa: E501
        :rtype: str
        """
        return self._auto_generate_assembly_id

    @auto_generate_assembly_id.setter
    def auto_generate_assembly_id(self, auto_generate_assembly_id):
        """Sets the auto_generate_assembly_id of this Version.

        The assembly unique Id used as reference when AutoGenerateAssembly is activated on the parent target.  Otherwise, set the property to Guid.Empty (00000000-0000-0000-0000-000000000000).  # noqa: E501

        :param auto_generate_assembly_id: The auto_generate_assembly_id of this Version.  # noqa: E501
        :type: str
        """

        self._auto_generate_assembly_id = auto_generate_assembly_id

    @property
    def last_update_date_utc(self):
        """Gets the last_update_date_utc of this Version.  # noqa: E501

        The last utc date time when the properties of the version have been updated  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_date_utc of this Version.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_date_utc

    @last_update_date_utc.setter
    def last_update_date_utc(self, last_update_date_utc):
        """Sets the last_update_date_utc of this Version.

        The last utc date time when the properties of the version have been updated  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_date_utc: The last_update_date_utc of this Version.  # noqa: E501
        :type: datetime
        """

        self._last_update_date_utc = last_update_date_utc

    @property
    def last_update_user(self):
        """Gets the last_update_user of this Version.  # noqa: E501

        The name of the last user having updated the assembly.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_user of this Version.  # noqa: E501
        :rtype: str
        """
        return self._last_update_user

    @last_update_user.setter
    def last_update_user(self, last_update_user):
        """Sets the last_update_user of this Version.

        The name of the last user having updated the assembly.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_user: The last_update_user of this Version.  # noqa: E501
        :type: str
        """

        self._last_update_user = last_update_user

    @property
    def replication_filter(self):
        """Gets the replication_filter of this Version.  # noqa: E501

        The level of the filter used for the replication  # noqa: E501

        :return: The replication_filter of this Version.  # noqa: E501
        :rtype: str
        """
        return self._replication_filter

    @replication_filter.setter
    def replication_filter(self, replication_filter):
        """Sets the replication_filter of this Version.

        The level of the filter used for the replication  # noqa: E501

        :param replication_filter: The replication_filter of this Version.  # noqa: E501
        :type: str
        """
        allowed_values = ["NotForReplication", "ForReplication"]  # noqa: E501
        if (self._configuration.client_side_validation and
                replication_filter not in allowed_values):
            raise ValueError(
                "Invalid value for `replication_filter` ({0}), must be one of {1}"  # noqa: E501
                .format(replication_filter, allowed_values)
            )

        self._replication_filter = replication_filter

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Version, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Version):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Version):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class Car(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'event_id': 'str',
        'type_car_id': 'str',
        'last_update_date_utc': 'datetime',
        'last_update_user': 'str',
        'revision': 'int',
        'lap_count': 'int',
        'run_count': 'int',
        'session_count': 'int',
        'distance': 'float',
        'distance_real': 'float'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'event_id': 'EventId',
        'type_car_id': 'TypeCarId',
        'last_update_date_utc': 'LastUpdateDateUtc',
        'last_update_user': 'LastUpdateUser',
        'revision': 'Revision',
        'lap_count': 'LapCount',
        'run_count': 'RunCount',
        'session_count': 'SessionCount',
        'distance': 'Distance',
        'distance_real': 'DistanceReal'
    }

    def __init__(self, id=None, name=None, event_id=None, type_car_id=None, last_update_date_utc=None, last_update_user=None, revision=None, lap_count=None, run_count=None, session_count=None, distance=None, distance_real=None, _configuration=None):  # noqa: E501
        """Car - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._event_id = None
        self._type_car_id = None
        self._last_update_date_utc = None
        self._last_update_user = None
        self._revision = None
        self._lap_count = None
        self._run_count = None
        self._session_count = None
        self._distance = None
        self._distance_real = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.event_id = event_id
        self.type_car_id = type_car_id
        if last_update_date_utc is not None:
            self.last_update_date_utc = last_update_date_utc
        if last_update_user is not None:
            self.last_update_user = last_update_user
        if revision is not None:
            self.revision = revision
        if lap_count is not None:
            self.lap_count = lap_count
        if run_count is not None:
            self.run_count = run_count
        if session_count is not None:
            self.session_count = session_count
        if distance is not None:
            self.distance = distance
        if distance_real is not None:
            self.distance_real = distance_real

    @property
    def id(self):
        """Gets the id of this Car.  # noqa: E501

        The unique car Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Car.  # noqa: E501

        :return: The id of this Car.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Car.

        The unique car Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Car.  # noqa: E501

        :param id: The id of this Car.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Car.  # noqa: E501

        The car name  # noqa: E501

        :return: The name of this Car.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Car.

        The car name  # noqa: E501

        :param name: The name of this Car.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def event_id(self):
        """Gets the event_id of this Car.  # noqa: E501

        The event unique id to which the car is linked.  # noqa: E501

        :return: The event_id of this Car.  # noqa: E501
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this Car.

        The event unique id to which the car is linked.  # noqa: E501

        :param event_id: The event_id of this Car.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and event_id is None:
            raise ValueError("Invalid value for `event_id`, must not be `None`")  # noqa: E501

        self._event_id = event_id

    @property
    def type_car_id(self):
        """Gets the type_car_id of this Car.  # noqa: E501

        The car type unique id.  # noqa: E501

        :return: The type_car_id of this Car.  # noqa: E501
        :rtype: str
        """
        return self._type_car_id

    @type_car_id.setter
    def type_car_id(self, type_car_id):
        """Sets the type_car_id of this Car.

        The car type unique id.  # noqa: E501

        :param type_car_id: The type_car_id of this Car.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and type_car_id is None:
            raise ValueError("Invalid value for `type_car_id`, must not be `None`")  # noqa: E501

        self._type_car_id = type_car_id

    @property
    def last_update_date_utc(self):
        """Gets the last_update_date_utc of this Car.  # noqa: E501

        The last utc date time when the properties of this object have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_date_utc of this Car.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_date_utc

    @last_update_date_utc.setter
    def last_update_date_utc(self, last_update_date_utc):
        """Sets the last_update_date_utc of this Car.

        The last utc date time when the properties of this object have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_date_utc: The last_update_date_utc of this Car.  # noqa: E501
        :type: datetime
        """

        self._last_update_date_utc = last_update_date_utc

    @property
    def last_update_user(self):
        """Gets the last_update_user of this Car.  # noqa: E501

        The name of the last user having updated this object.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_user of this Car.  # noqa: E501
        :rtype: str
        """
        return self._last_update_user

    @last_update_user.setter
    def last_update_user(self, last_update_user):
        """Sets the last_update_user of this Car.

        The name of the last user having updated this object.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_user: The last_update_user of this Car.  # noqa: E501
        :type: str
        """

        self._last_update_user = last_update_user

    @property
    def revision(self):
        """Gets the revision of this Car.  # noqa: E501

        The revision number of the object.  # noqa: E501

        :return: The revision of this Car.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this Car.

        The revision number of the object.  # noqa: E501

        :param revision: The revision of this Car.  # noqa: E501
        :type: int
        """

        self._revision = revision

    @property
    def lap_count(self):
        """Gets the lap_count of this Car.  # noqa: E501

        Lap count for the car  # noqa: E501

        :return: The lap_count of this Car.  # noqa: E501
        :rtype: int
        """
        return self._lap_count

    @lap_count.setter
    def lap_count(self, lap_count):
        """Sets the lap_count of this Car.

        Lap count for the car  # noqa: E501

        :param lap_count: The lap_count of this Car.  # noqa: E501
        :type: int
        """

        self._lap_count = lap_count

    @property
    def run_count(self):
        """Gets the run_count of this Car.  # noqa: E501

        Run count for the car  # noqa: E501

        :return: The run_count of this Car.  # noqa: E501
        :rtype: int
        """
        return self._run_count

    @run_count.setter
    def run_count(self, run_count):
        """Sets the run_count of this Car.

        Run count for the car  # noqa: E501

        :param run_count: The run_count of this Car.  # noqa: E501
        :type: int
        """

        self._run_count = run_count

    @property
    def session_count(self):
        """Gets the session_count of this Car.  # noqa: E501

        Session count for the car  # noqa: E501

        :return: The session_count of this Car.  # noqa: E501
        :rtype: int
        """
        return self._session_count

    @session_count.setter
    def session_count(self, session_count):
        """Sets the session_count of this Car.

        Session count for the car  # noqa: E501

        :param session_count: The session_count of this Car.  # noqa: E501
        :type: int
        """

        self._session_count = session_count

    @property
    def distance(self):
        """Gets the distance of this Car.  # noqa: E501

        Distance performed by the car  # noqa: E501

        :return: The distance of this Car.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this Car.

        Distance performed by the car  # noqa: E501

        :param distance: The distance of this Car.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def distance_real(self):
        """Gets the distance_real of this Car.  # noqa: E501

        Distance real performed by the car  # noqa: E501

        :return: The distance_real of this Car.  # noqa: E501
        :rtype: float
        """
        return self._distance_real

    @distance_real.setter
    def distance_real(self, distance_real):
        """Sets the distance_real of this Car.

        Distance real performed by the car  # noqa: E501

        :param distance_real: The distance_real of this Car.  # noqa: E501
        :type: float
        """

        self._distance_real = distance_real

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Car, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Car):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Car):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class Lap(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'number': 'int',
        'absolute_number': 'int',
        'order': 'int',
        'run_id': 'str',
        'lap_date': 'datetime',
        'lap_time': 'float',
        'is_valid': 'bool',
        'last_update_date_utc': 'datetime',
        'last_update_user': 'str',
        'revision': 'int',
        'distance_real': 'float',
        'tire_fl_sliding_energy': 'float',
        'tire_fr_sliding_energy': 'float',
        'tire_rl_sliding_energy': 'float',
        'tire_rr_sliding_energy': 'float',
        'distance_power': 'float',
        'lap_time_power': 'float',
        'energy': 'float',
        'time_of_day': 'str',
        'consumption': 'float',
        'used_in_run_plan': 'bool'
    }

    attribute_map = {
        'id': 'Id',
        'number': 'Number',
        'absolute_number': 'AbsoluteNumber',
        'order': 'Order',
        'run_id': 'RunId',
        'lap_date': 'LapDate',
        'lap_time': 'LapTime',
        'is_valid': 'IsValid',
        'last_update_date_utc': 'LastUpdateDateUtc',
        'last_update_user': 'LastUpdateUser',
        'revision': 'Revision',
        'distance_real': 'DistanceReal',
        'tire_fl_sliding_energy': 'TireFL_SlidingEnergy',
        'tire_fr_sliding_energy': 'TireFR_SlidingEnergy',
        'tire_rl_sliding_energy': 'TireRL_SlidingEnergy',
        'tire_rr_sliding_energy': 'TireRR_SlidingEnergy',
        'distance_power': 'DistancePower',
        'lap_time_power': 'LapTimePower',
        'energy': 'Energy',
        'time_of_day': 'TimeOfDay',
        'consumption': 'Consumption',
        'used_in_run_plan': 'UsedInRunPlan'
    }

    def __init__(self, id=None, number=None, absolute_number=None, order=None, run_id=None, lap_date=None, lap_time=None, is_valid=True, last_update_date_utc=None, last_update_user=None, revision=None, distance_real=None, tire_fl_sliding_energy=None, tire_fr_sliding_energy=None, tire_rl_sliding_energy=None, tire_rr_sliding_energy=None, distance_power=None, lap_time_power=None, energy=None, time_of_day=None, consumption=None, used_in_run_plan=True, _configuration=None):  # noqa: E501
        """Lap - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._number = None
        self._absolute_number = None
        self._order = None
        self._run_id = None
        self._lap_date = None
        self._lap_time = None
        self._is_valid = None
        self._last_update_date_utc = None
        self._last_update_user = None
        self._revision = None
        self._distance_real = None
        self._tire_fl_sliding_energy = None
        self._tire_fr_sliding_energy = None
        self._tire_rl_sliding_energy = None
        self._tire_rr_sliding_energy = None
        self._distance_power = None
        self._lap_time_power = None
        self._energy = None
        self._time_of_day = None
        self._consumption = None
        self._used_in_run_plan = None
        self.discriminator = None

        self.id = id
        self.number = number
        self.absolute_number = absolute_number
        self.order = order
        self.run_id = run_id
        self.lap_date = lap_date
        self.lap_time = lap_time
        if is_valid is not None:
            self.is_valid = is_valid
        if last_update_date_utc is not None:
            self.last_update_date_utc = last_update_date_utc
        if last_update_user is not None:
            self.last_update_user = last_update_user
        if revision is not None:
            self.revision = revision
        if distance_real is not None:
            self.distance_real = distance_real
        if tire_fl_sliding_energy is not None:
            self.tire_fl_sliding_energy = tire_fl_sliding_energy
        if tire_fr_sliding_energy is not None:
            self.tire_fr_sliding_energy = tire_fr_sliding_energy
        if tire_rl_sliding_energy is not None:
            self.tire_rl_sliding_energy = tire_rl_sliding_energy
        if tire_rr_sliding_energy is not None:
            self.tire_rr_sliding_energy = tire_rr_sliding_energy
        if distance_power is not None:
            self.distance_power = distance_power
        if lap_time_power is not None:
            self.lap_time_power = lap_time_power
        if energy is not None:
            self.energy = energy
        if time_of_day is not None:
            self.time_of_day = time_of_day
        if consumption is not None:
            self.consumption = consumption
        if used_in_run_plan is not None:
            self.used_in_run_plan = used_in_run_plan

    @property
    def id(self):
        """Gets the id of this Lap.  # noqa: E501

        The lap id.  # noqa: E501

        :return: The id of this Lap.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Lap.

        The lap id.  # noqa: E501

        :param id: The id of this Lap.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def number(self):
        """Gets the number of this Lap.  # noqa: E501

        The lap number.  # noqa: E501

        :return: The number of this Lap.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this Lap.

        The lap number.  # noqa: E501

        :param number: The number of this Lap.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and number is None:
            raise ValueError("Invalid value for `number`, must not be `None`")  # noqa: E501

        self._number = number

    @property
    def absolute_number(self):
        """Gets the absolute_number of this Lap.  # noqa: E501

        The lap absolute number.  # noqa: E501

        :return: The absolute_number of this Lap.  # noqa: E501
        :rtype: int
        """
        return self._absolute_number

    @absolute_number.setter
    def absolute_number(self, absolute_number):
        """Sets the absolute_number of this Lap.

        The lap absolute number.  # noqa: E501

        :param absolute_number: The absolute_number of this Lap.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and absolute_number is None:
            raise ValueError("Invalid value for `absolute_number`, must not be `None`")  # noqa: E501

        self._absolute_number = absolute_number

    @property
    def order(self):
        """Gets the order of this Lap.  # noqa: E501

        The lap order.  # noqa: E501

        :return: The order of this Lap.  # noqa: E501
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this Lap.

        The lap order.  # noqa: E501

        :param order: The order of this Lap.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and order is None:
            raise ValueError("Invalid value for `order`, must not be `None`")  # noqa: E501

        self._order = order

    @property
    def run_id(self):
        """Gets the run_id of this Lap.  # noqa: E501

        The run unique id to which the lap is linked.  # noqa: E501

        :return: The run_id of this Lap.  # noqa: E501
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this Lap.

        The run unique id to which the lap is linked.  # noqa: E501

        :param run_id: The run_id of this Lap.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and run_id is None:
            raise ValueError("Invalid value for `run_id`, must not be `None`")  # noqa: E501

        self._run_id = run_id

    @property
    def lap_date(self):
        """Gets the lap_date of this Lap.  # noqa: E501

        The lap date.  The date must be an UTC date time. Here is an example : 2018-06-05T12:36:34.168Z  # noqa: E501

        :return: The lap_date of this Lap.  # noqa: E501
        :rtype: datetime
        """
        return self._lap_date

    @lap_date.setter
    def lap_date(self, lap_date):
        """Sets the lap_date of this Lap.

        The lap date.  The date must be an UTC date time. Here is an example : 2018-06-05T12:36:34.168Z  # noqa: E501

        :param lap_date: The lap_date of this Lap.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and lap_date is None:
            raise ValueError("Invalid value for `lap_date`, must not be `None`")  # noqa: E501

        self._lap_date = lap_date

    @property
    def lap_time(self):
        """Gets the lap_time of this Lap.  # noqa: E501

        The lap time in seconds.  # noqa: E501

        :return: The lap_time of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._lap_time

    @lap_time.setter
    def lap_time(self, lap_time):
        """Sets the lap_time of this Lap.

        The lap time in seconds.  # noqa: E501

        :param lap_time: The lap_time of this Lap.  # noqa: E501
        :type: float
        """
        if self._configuration.client_side_validation and lap_time is None:
            raise ValueError("Invalid value for `lap_time`, must not be `None`")  # noqa: E501

        self._lap_time = lap_time

    @property
    def is_valid(self):
        """Gets the is_valid of this Lap.  # noqa: E501

        The lap \"valid\" status.  # noqa: E501

        :return: The is_valid of this Lap.  # noqa: E501
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """Sets the is_valid of this Lap.

        The lap \"valid\" status.  # noqa: E501

        :param is_valid: The is_valid of this Lap.  # noqa: E501
        :type: bool
        """

        self._is_valid = is_valid

    @property
    def last_update_date_utc(self):
        """Gets the last_update_date_utc of this Lap.  # noqa: E501

        The last utc date time when the properties of this object have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_date_utc of this Lap.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_date_utc

    @last_update_date_utc.setter
    def last_update_date_utc(self, last_update_date_utc):
        """Sets the last_update_date_utc of this Lap.

        The last utc date time when the properties of this object have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_date_utc: The last_update_date_utc of this Lap.  # noqa: E501
        :type: datetime
        """

        self._last_update_date_utc = last_update_date_utc

    @property
    def last_update_user(self):
        """Gets the last_update_user of this Lap.  # noqa: E501

        The name of the last user having updated this object.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_user of this Lap.  # noqa: E501
        :rtype: str
        """
        return self._last_update_user

    @last_update_user.setter
    def last_update_user(self, last_update_user):
        """Sets the last_update_user of this Lap.

        The name of the last user having updated this object.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_user: The last_update_user of this Lap.  # noqa: E501
        :type: str
        """

        self._last_update_user = last_update_user

    @property
    def revision(self):
        """Gets the revision of this Lap.  # noqa: E501

        The revision number of the object.  # noqa: E501

        :return: The revision of this Lap.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this Lap.

        The revision number of the object.  # noqa: E501

        :param revision: The revision of this Lap.  # noqa: E501
        :type: int
        """

        self._revision = revision

    @property
    def distance_real(self):
        """Gets the distance_real of this Lap.  # noqa: E501

        Real distance performed  # noqa: E501

        :return: The distance_real of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._distance_real

    @distance_real.setter
    def distance_real(self, distance_real):
        """Sets the distance_real of this Lap.

        Real distance performed  # noqa: E501

        :param distance_real: The distance_real of this Lap.  # noqa: E501
        :type: float
        """

        self._distance_real = distance_real

    @property
    def tire_fl_sliding_energy(self):
        """Gets the tire_fl_sliding_energy of this Lap.  # noqa: E501

        énergie obtenue pour le pneu FL durant le lap  # noqa: E501

        :return: The tire_fl_sliding_energy of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._tire_fl_sliding_energy

    @tire_fl_sliding_energy.setter
    def tire_fl_sliding_energy(self, tire_fl_sliding_energy):
        """Sets the tire_fl_sliding_energy of this Lap.

        énergie obtenue pour le pneu FL durant le lap  # noqa: E501

        :param tire_fl_sliding_energy: The tire_fl_sliding_energy of this Lap.  # noqa: E501
        :type: float
        """

        self._tire_fl_sliding_energy = tire_fl_sliding_energy

    @property
    def tire_fr_sliding_energy(self):
        """Gets the tire_fr_sliding_energy of this Lap.  # noqa: E501

        énergie obtenue pour le pneu FR durant le lap  # noqa: E501

        :return: The tire_fr_sliding_energy of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._tire_fr_sliding_energy

    @tire_fr_sliding_energy.setter
    def tire_fr_sliding_energy(self, tire_fr_sliding_energy):
        """Sets the tire_fr_sliding_energy of this Lap.

        énergie obtenue pour le pneu FR durant le lap  # noqa: E501

        :param tire_fr_sliding_energy: The tire_fr_sliding_energy of this Lap.  # noqa: E501
        :type: float
        """

        self._tire_fr_sliding_energy = tire_fr_sliding_energy

    @property
    def tire_rl_sliding_energy(self):
        """Gets the tire_rl_sliding_energy of this Lap.  # noqa: E501

        énergie obtenue pour le pneu RL durant le lap  # noqa: E501

        :return: The tire_rl_sliding_energy of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._tire_rl_sliding_energy

    @tire_rl_sliding_energy.setter
    def tire_rl_sliding_energy(self, tire_rl_sliding_energy):
        """Sets the tire_rl_sliding_energy of this Lap.

        énergie obtenue pour le pneu RL durant le lap  # noqa: E501

        :param tire_rl_sliding_energy: The tire_rl_sliding_energy of this Lap.  # noqa: E501
        :type: float
        """

        self._tire_rl_sliding_energy = tire_rl_sliding_energy

    @property
    def tire_rr_sliding_energy(self):
        """Gets the tire_rr_sliding_energy of this Lap.  # noqa: E501

        énergie obtenue pour le pneu RR durant le lap  # noqa: E501

        :return: The tire_rr_sliding_energy of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._tire_rr_sliding_energy

    @tire_rr_sliding_energy.setter
    def tire_rr_sliding_energy(self, tire_rr_sliding_energy):
        """Sets the tire_rr_sliding_energy of this Lap.

        énergie obtenue pour le pneu RR durant le lap  # noqa: E501

        :param tire_rr_sliding_energy: The tire_rr_sliding_energy of this Lap.  # noqa: E501
        :type: float
        """

        self._tire_rr_sliding_energy = tire_rr_sliding_energy

    @property
    def distance_power(self):
        """Gets the distance_power of this Lap.  # noqa: E501

        Distance covered in power  # noqa: E501

        :return: The distance_power of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._distance_power

    @distance_power.setter
    def distance_power(self, distance_power):
        """Sets the distance_power of this Lap.

        Distance covered in power  # noqa: E501

        :param distance_power: The distance_power of this Lap.  # noqa: E501
        :type: float
        """

        self._distance_power = distance_power

    @property
    def lap_time_power(self):
        """Gets the lap_time_power of this Lap.  # noqa: E501

        Time elpased in power  # noqa: E501

        :return: The lap_time_power of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._lap_time_power

    @lap_time_power.setter
    def lap_time_power(self, lap_time_power):
        """Sets the lap_time_power of this Lap.

        Time elpased in power  # noqa: E501

        :param lap_time_power: The lap_time_power of this Lap.  # noqa: E501
        :type: float
        """

        self._lap_time_power = lap_time_power

    @property
    def energy(self):
        """Gets the energy of this Lap.  # noqa: E501

        Lap energy  # noqa: E501

        :return: The energy of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._energy

    @energy.setter
    def energy(self, energy):
        """Sets the energy of this Lap.

        Lap energy  # noqa: E501

        :param energy: The energy of this Lap.  # noqa: E501
        :type: float
        """

        self._energy = energy

    @property
    def time_of_day(self):
        """Gets the time_of_day of this Lap.  # noqa: E501

        Le time of the day de la télémétrie  # noqa: E501

        :return: The time_of_day of this Lap.  # noqa: E501
        :rtype: str
        """
        return self._time_of_day

    @time_of_day.setter
    def time_of_day(self, time_of_day):
        """Sets the time_of_day of this Lap.

        Le time of the day de la télémétrie  # noqa: E501

        :param time_of_day: The time_of_day of this Lap.  # noqa: E501
        :type: str
        """

        self._time_of_day = time_of_day

    @property
    def consumption(self):
        """Gets the consumption of this Lap.  # noqa: E501

        Le niveau de consommation d'énergie  # noqa: E501

        :return: The consumption of this Lap.  # noqa: E501
        :rtype: float
        """
        return self._consumption

    @consumption.setter
    def consumption(self, consumption):
        """Sets the consumption of this Lap.

        Le niveau de consommation d'énergie  # noqa: E501

        :param consumption: The consumption of this Lap.  # noqa: E501
        :type: float
        """

        self._consumption = consumption

    @property
    def used_in_run_plan(self):
        """Gets the used_in_run_plan of this Lap.  # noqa: E501

        Indique si le lap peut être utilisé par le run plan  # noqa: E501

        :return: The used_in_run_plan of this Lap.  # noqa: E501
        :rtype: bool
        """
        return self._used_in_run_plan

    @used_in_run_plan.setter
    def used_in_run_plan(self, used_in_run_plan):
        """Sets the used_in_run_plan of this Lap.

        Indique si le lap peut être utilisé par le run plan  # noqa: E501

        :param used_in_run_plan: The used_in_run_plan of this Lap.  # noqa: E501
        :type: bool
        """

        self._used_in_run_plan = used_in_run_plan

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Lap, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Lap):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Lap):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class NotesAuthorization(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'concerned_entity_id': 'str',
        'concerned_entity_is_group': 'bool',
        'item_base_id': 'str',
        'has_acces': 'bool'
    }

    attribute_map = {
        'id': 'Id',
        'concerned_entity_id': 'ConcernedEntityId',
        'concerned_entity_is_group': 'ConcernedEntityIsGroup',
        'item_base_id': 'ItemBaseId',
        'has_acces': 'HasAcces'
    }

    def __init__(self, id=None, concerned_entity_id=None, concerned_entity_is_group=None, item_base_id=None, has_acces=None, _configuration=None):  # noqa: E501
        """NotesAuthorization - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._concerned_entity_id = None
        self._concerned_entity_is_group = None
        self._item_base_id = None
        self._has_acces = None
        self.discriminator = None

        self.id = id
        self.concerned_entity_id = concerned_entity_id
        if concerned_entity_is_group is not None:
            self.concerned_entity_is_group = concerned_entity_is_group
        self.item_base_id = item_base_id
        self.has_acces = has_acces

    @property
    def id(self):
        """Gets the id of this NotesAuthorization.  # noqa: E501

        The unique authorization Id.  # noqa: E501

        :return: The id of this NotesAuthorization.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this NotesAuthorization.

        The unique authorization Id.  # noqa: E501

        :param id: The id of this NotesAuthorization.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def concerned_entity_id(self):
        """Gets the concerned_entity_id of this NotesAuthorization.  # noqa: E501

        The unique id of the concerned entity (user or group).  # noqa: E501

        :return: The concerned_entity_id of this NotesAuthorization.  # noqa: E501
        :rtype: str
        """
        return self._concerned_entity_id

    @concerned_entity_id.setter
    def concerned_entity_id(self, concerned_entity_id):
        """Sets the concerned_entity_id of this NotesAuthorization.

        The unique id of the concerned entity (user or group).  # noqa: E501

        :param concerned_entity_id: The concerned_entity_id of this NotesAuthorization.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and concerned_entity_id is None:
            raise ValueError("Invalid value for `concerned_entity_id`, must not be `None`")  # noqa: E501

        self._concerned_entity_id = concerned_entity_id

    @property
    def concerned_entity_is_group(self):
        """Gets the concerned_entity_is_group of this NotesAuthorization.  # noqa: E501

        Set to True if `ConcernedEntityId` is a group id.  # noqa: E501

        :return: The concerned_entity_is_group of this NotesAuthorization.  # noqa: E501
        :rtype: bool
        """
        return self._concerned_entity_is_group

    @concerned_entity_is_group.setter
    def concerned_entity_is_group(self, concerned_entity_is_group):
        """Sets the concerned_entity_is_group of this NotesAuthorization.

        Set to True if `ConcernedEntityId` is a group id.  # noqa: E501

        :param concerned_entity_is_group: The concerned_entity_is_group of this NotesAuthorization.  # noqa: E501
        :type: bool
        """

        self._concerned_entity_is_group = concerned_entity_is_group

    @property
    def item_base_id(self):
        """Gets the item_base_id of this NotesAuthorization.  # noqa: E501

        The itemBase (event or car) id to which this authorization belongs.  # noqa: E501

        :return: The item_base_id of this NotesAuthorization.  # noqa: E501
        :rtype: str
        """
        return self._item_base_id

    @item_base_id.setter
    def item_base_id(self, item_base_id):
        """Sets the item_base_id of this NotesAuthorization.

        The itemBase (event or car) id to which this authorization belongs.  # noqa: E501

        :param item_base_id: The item_base_id of this NotesAuthorization.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and item_base_id is None:
            raise ValueError("Invalid value for `item_base_id`, must not be `None`")  # noqa: E501

        self._item_base_id = item_base_id

    @property
    def has_acces(self):
        """Gets the has_acces of this NotesAuthorization.  # noqa: E501

        Set to True to allow the user/group to access to the event or car.  # noqa: E501

        :return: The has_acces of this NotesAuthorization.  # noqa: E501
        :rtype: bool
        """
        return self._has_acces

    @has_acces.setter
    def has_acces(self, has_acces):
        """Sets the has_acces of this NotesAuthorization.

        Set to True to allow the user/group to access to the event or car.  # noqa: E501

        :param has_acces: The has_acces of this NotesAuthorization.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and has_acces is None:
            raise ValueError("Invalid value for `has_acces`, must not be `None`")  # noqa: E501

        self._has_acces = has_acces

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NotesAuthorization, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotesAuthorization):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NotesAuthorization):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class EventApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def event_create_event(self, new_event, **kwargs):  # noqa: E501
        """Create a new event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_create_event(new_event, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Event new_event: The event to create. (required)
        :return: Event
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.event_create_event_with_http_info(new_event, **kwargs)  # noqa: E501
        else:
            (data) = self.event_create_event_with_http_info(new_event, **kwargs)  # noqa: E501
            return data

    def event_create_event_with_http_info(self, new_event, **kwargs):  # noqa: E501
        """Create a new event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_create_event_with_http_info(new_event, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Event new_event: The event to create. (required)
        :return: Event
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['new_event']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method event_create_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'new_event' is set
        if self.api_client.client_side_validation and ('new_event' not in params or
                                                       params['new_event'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `new_event` when calling `event_create_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'new_event' in params:
            body_params = params['new_event']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/event', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Event',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def event_delete_event(self, event_id, **kwargs):  # noqa: E501
        """Delete an existing event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_delete_event(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The unique event id for which you want to delete the event (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.event_delete_event_with_http_info(event_id, **kwargs)  # noqa: E501
        else:
            (data) = self.event_delete_event_with_http_info(event_id, **kwargs)  # noqa: E501
            return data

    def event_delete_event_with_http_info(self, event_id, **kwargs):  # noqa: E501
        """Delete an existing event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_delete_event_with_http_info(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The unique event id for which you want to delete the event (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method event_delete_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if self.api_client.client_side_validation and ('event_id' not in params or
                                                       params['event_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `event_id` when calling `event_delete_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['eventId'] = params['event_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/event/{eventId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def event_get_current_event(self, **kwargs):  # noqa: E501
        """Get the current event.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_get_current_event(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Event
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.event_get_current_event_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.event_get_current_event_with_http_info(**kwargs)  # noqa: E501
            return data

    def event_get_current_event_with_http_info(self, **kwargs):  # noqa: E501
        """Get the current event.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_get_current_event_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Event
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method event_get_current_event" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/event/current', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Event',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def event_get_event(self, event_id, **kwargs):  # noqa: E501
        """Get an event via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_get_event(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The unique event id for which you want to get the event (required)
        :return: Event
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.event_get_event_with_http_info(event_id, **kwargs)  # noqa: E501
        else:
            (data) = self.event_get_event_with_http_info(event_id, **kwargs)  # noqa: E501
            return data

    def event_get_event_with_http_info(self, event_id, **kwargs):  # noqa: E501
        """Get an event via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_get_event_with_http_info(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The unique event id for which you want to get the event (required)
        :return: Event
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method event_get_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if self.api_client.client_side_validation and ('event_id' not in params or
                                                       params['event_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `event_id` when calling `event_get_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['eventId'] = params['event_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/event/{eventId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Event',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def event_get_events(self, **kwargs):  # noqa: E501
        """Get the list of all events  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_get_events(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.event_get_events_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.event_get_events_with_http_info(**kwargs)  # noqa: E501
            return data

    def event_get_events_with_http_info(self, **kwargs):  # noqa: E501
        """Get the list of all events  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_get_events_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method event_get_events" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CoupleGuidText]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def event_load_all_data_event(self, event_id, **kwargs):  # noqa: E501
        """[Command] Load all data (cars, sessions, runs, laps) for an event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_load_all_data_event(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event id for which you want to load data. (required)
        :param bool reset_cache: Set to \"true\" to reset the cache and force to reload all data.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.event_load_all_data_event_with_http_info(event_id, **kwargs)  # noqa: E501
        else:
            (data) = self.event_load_all_data_event_with_http_info(event_id, **kwargs)  # noqa: E501
            return data

    def event_load_all_data_event_with_http_info(self, event_id, **kwargs):  # noqa: E501
        """[Command] Load all data (cars, sessions, runs, laps) for an event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_load_all_data_event_with_http_info(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event id for which you want to load data. (required)
        :param bool reset_cache: Set to \"true\" to reset the cache and force to reload all data.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id', 'reset_cache']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method event_load_all_data_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if self.api_client.client_side_validation and ('event_id' not in params or
                                                       params['event_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `event_id` when calling `event_load_all_data_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['eventId'] = params['event_id']  # noqa: E501

        query_params = []
        if 'reset_cache' in params:
            query_params.append(('resetCache', params['reset_cache']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/event/{eventId}/loadalldata', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def event_lock_event(self, event_id, **kwargs):  # noqa: E501
        """[Command] Lock an event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_lock_event(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The unique event id for which you want to lock the event (required)
        :param bool force_on_my_server: If true force the lock on your server even if it exists a lock on another server. If you force the lock on this server, this may cause conflicts durring the next replication of the databases and corrupt them.
        :return: Event
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.event_lock_event_with_http_info(event_id, **kwargs)  # noqa: E501
        else:
            (data) = self.event_lock_event_with_http_info(event_id, **kwargs)  # noqa: E501
            return data

    def event_lock_event_with_http_info(self, event_id, **kwargs):  # noqa: E501
        """[Command] Lock an event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_lock_event_with_http_info(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The unique event id for which you want to lock the event (required)
        :param bool force_on_my_server: If true force the lock on your server even if it exists a lock on another server. If you force the lock on this server, this may cause conflicts durring the next replication of the databases and corrupt them.
        :return: Event
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id', 'force_on_my_server']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method event_lock_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if self.api_client.client_side_validation and ('event_id' not in params or
                                                       params['event_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `event_id` when calling `event_lock_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['eventId'] = params['event_id']  # noqa: E501

        query_params = []
        if 'force_on_my_server' in params:
            query_params.append(('forceOnMyServer', params['force_on_my_server']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/event/{eventId}/lock', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Event',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def event_release_event(self, event_id, **kwargs):  # noqa: E501
        """[Command] Release an event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_release_event(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The unique event id for which you want to release the event (required)
        :return: Event
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.event_release_event_with_http_info(event_id, **kwargs)  # noqa: E501
        else:
            (data) = self.event_release_event_with_http_info(event_id, **kwargs)  # noqa: E501
            return data

    def event_release_event_with_http_info(self, event_id, **kwargs):  # noqa: E501
        """[Command] Release an event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_release_event_with_http_info(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The unique event id for which you want to release the event (required)
        :return: Event
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method event_release_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if self.api_client.client_side_validation and ('event_id' not in params or
                                                       params['event_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `event_id` when calling `event_release_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['eventId'] = params['event_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/event/{eventId}/release', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Event',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def event_update_event(self, event_id, updated_event, **kwargs):  # noqa: E501
        """Update an existing event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_update_event(event_id, updated_event, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The unique event id for which you want to update the event (required)
        :param Event updated_event: The event to update. (required)
        :return: Event
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.event_update_event_with_http_info(event_id, updated_event, **kwargs)  # noqa: E501
        else:
            (data) = self.event_update_event_with_http_info(event_id, updated_event, **kwargs)  # noqa: E501
            return data

    def event_update_event_with_http_info(self, event_id, updated_event, **kwargs):  # noqa: E501
        """Update an existing event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.event_update_event_with_http_info(event_id, updated_event, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The unique event id for which you want to update the event (required)
        :param Event updated_event: The event to update. (required)
        :return: Event
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id', 'updated_event']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method event_update_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if self.api_client.client_side_validation and ('event_id' not in params or
                                                       params['event_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `event_id` when calling `event_update_event`")  # noqa: E501
        # verify the required parameter 'updated_event' is set
        if self.api_client.client_side_validation and ('updated_event' not in params or
                                                       params['updated_event'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `updated_event` when calling `event_update_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['eventId'] = params['event_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'updated_event' in params:
            body_params = params['updated_event']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/event/{eventId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Event',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class LapApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def lap_create_new_lap(self, run_id, **kwargs):  # noqa: E501
        """Create a new lap  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_create_new_lap(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str run_id: The run id to which you want to add a new lap. (required)
        :return: Lap
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lap_create_new_lap_with_http_info(run_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lap_create_new_lap_with_http_info(run_id, **kwargs)  # noqa: E501
            return data

    def lap_create_new_lap_with_http_info(self, run_id, **kwargs):  # noqa: E501
        """Create a new lap  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_create_new_lap_with_http_info(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str run_id: The run id to which you want to add a new lap. (required)
        :return: Lap
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['run_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lap_create_new_lap" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in params or
                                                       params['run_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `run_id` when calling `lap_create_new_lap`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'run_id' in params:
            path_params['runId'] = params['run_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/run/{runId}/addlap', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Lap',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lap_delete_lap(self, lap_id, **kwargs):  # noqa: E501
        """Delete an existing lap  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_delete_lap(lap_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str lap_id: The unique lap id for which you want to delete the lap (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lap_delete_lap_with_http_info(lap_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lap_delete_lap_with_http_info(lap_id, **kwargs)  # noqa: E501
            return data

    def lap_delete_lap_with_http_info(self, lap_id, **kwargs):  # noqa: E501
        """Delete an existing lap  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_delete_lap_with_http_info(lap_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str lap_id: The unique lap id for which you want to delete the lap (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['lap_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lap_delete_lap" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'lap_id' is set
        if self.api_client.client_side_validation and ('lap_id' not in params or
                                                       params['lap_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `lap_id` when calling `lap_delete_lap`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'lap_id' in params:
            path_params['lapId'] = params['lap_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/lap/{lapId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lap_get_current_lap(self, **kwargs):  # noqa: E501
        """Get the current lap.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_get_current_lap(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Lap
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lap_get_current_lap_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.lap_get_current_lap_with_http_info(**kwargs)  # noqa: E501
            return data

    def lap_get_current_lap_with_http_info(self, **kwargs):  # noqa: E501
        """Get the current lap.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_get_current_lap_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Lap
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lap_get_current_lap" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/lap/current', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Lap',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lap_get_lap(self, lap_id, **kwargs):  # noqa: E501
        """Get a lap via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_get_lap(lap_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str lap_id: The unique lap id for which you want to get the lap (required)
        :return: Lap
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lap_get_lap_with_http_info(lap_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lap_get_lap_with_http_info(lap_id, **kwargs)  # noqa: E501
            return data

    def lap_get_lap_with_http_info(self, lap_id, **kwargs):  # noqa: E501
        """Get a lap via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_get_lap_with_http_info(lap_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str lap_id: The unique lap id for which you want to get the lap (required)
        :return: Lap
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['lap_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lap_get_lap" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'lap_id' is set
        if self.api_client.client_side_validation and ('lap_id' not in params or
                                                       params['lap_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `lap_id` when calling `lap_get_lap`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'lap_id' in params:
            path_params['lapId'] = params['lap_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/lap/{lapId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Lap',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lap_get_lap_list(self, run_id, **kwargs):  # noqa: E501
        """Get the list of all laps for a run.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_get_lap_list(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str run_id: The unique run id for which you want to get the lap list (required)
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lap_get_lap_list_with_http_info(run_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lap_get_lap_list_with_http_info(run_id, **kwargs)  # noqa: E501
            return data

    def lap_get_lap_list_with_http_info(self, run_id, **kwargs):  # noqa: E501
        """Get the list of all laps for a run.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_get_lap_list_with_http_info(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str run_id: The unique run id for which you want to get the lap list (required)
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['run_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lap_get_lap_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in params or
                                                       params['run_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `run_id` when calling `lap_get_lap_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'run_id' in params:
            path_params['runId'] = params['run_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/run/{runId}/laps', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CoupleGuidText]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lap_update_lap_property(self, lap_id, property_name, value, **kwargs):  # noqa: E501
        """Update a property value for an existing lap  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_update_lap_property(lap_id, property_name, value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str lap_id: The lap unique Id (required)
        :param str property_name: The property name to update. (Case sensitive). (required)
        :param object value: The new value. For LapDate, you need to wrap the date around \" for instance : \"2018-12-20T09:31:25.111Z\" (required)
        :return: Lap
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lap_update_lap_property_with_http_info(lap_id, property_name, value, **kwargs)  # noqa: E501
        else:
            (data) = self.lap_update_lap_property_with_http_info(lap_id, property_name, value, **kwargs)  # noqa: E501
            return data

    def lap_update_lap_property_with_http_info(self, lap_id, property_name, value, **kwargs):  # noqa: E501
        """Update a property value for an existing lap  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_update_lap_property_with_http_info(lap_id, property_name, value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str lap_id: The lap unique Id (required)
        :param str property_name: The property name to update. (Case sensitive). (required)
        :param object value: The new value. For LapDate, you need to wrap the date around \" for instance : \"2018-12-20T09:31:25.111Z\" (required)
        :return: Lap
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['lap_id', 'property_name', 'value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lap_update_lap_property" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'lap_id' is set
        if self.api_client.client_side_validation and ('lap_id' not in params or
                                                       params['lap_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `lap_id` when calling `lap_update_lap_property`")  # noqa: E501
        # verify the required parameter 'property_name' is set
        if self.api_client.client_side_validation and ('property_name' not in params or
                                                       params['property_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `property_name` when calling `lap_update_lap_property`")  # noqa: E501
        # verify the required parameter 'value' is set
        if self.api_client.client_side_validation and ('value' not in params or
                                                       params['value'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `value` when calling `lap_update_lap_property`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'lap_id' in params:
            path_params['lapId'] = params['lap_id']  # noqa: E501
        if 'property_name' in params:
            path_params['propertyName'] = params['property_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/lap/{lapId}/propertyName/{propertyName}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Lap',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lap_update_lap(self, lap_id, lap_to_update, **kwargs):  # noqa: E501
        """Update an existing lap  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_update_lap(lap_id, lap_to_update, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str lap_id: The Id of the lap to update (required)
        :param Lap lap_to_update: The lap to update (required)
        :return: Lap
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lap_update_lap_with_http_info(lap_id, lap_to_update, **kwargs)  # noqa: E501
        else:
            (data) = self.lap_update_lap_with_http_info(lap_id, lap_to_update, **kwargs)  # noqa: E501
            return data

    def lap_update_lap_with_http_info(self, lap_id, lap_to_update, **kwargs):  # noqa: E501
        """Update an existing lap  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_update_lap_with_http_info(lap_id, lap_to_update, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str lap_id: The Id of the lap to update (required)
        :param Lap lap_to_update: The lap to update (required)
        :return: Lap
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['lap_id', 'lap_to_update']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lap_update_lap" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'lap_id' is set
        if self.api_client.client_side_validation and ('lap_id' not in params or
                                                       params['lap_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `lap_id` when calling `lap_update_lap`")  # noqa: E501
        # verify the required parameter 'lap_to_update' is set
        if self.api_client.client_side_validation and ('lap_to_update' not in params or
                                                       params['lap_to_update'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `lap_to_update` when calling `lap_update_lap`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'lap_id' in params:
            path_params['lapId'] = params['lap_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'lap_to_update' in params:
            body_params = params['lap_to_update']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/lap/{lapId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Lap',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
